## What does this MR do and why?

_Describe in detail what your merge request does and why._

<!--
Please keep this description updated with any discussion that takes place so
that reviewers can understand your intent. Keeping the description updated is
especially important if they didn't participate in the discussion.

Please add "Fixes #<issue number>" if relevant
-->

%{first_multiline_commit}

## How to set up and validate locally

_Numbered steps to set up and validate the change are strongly suggested._

<!--
Example below:

1. Enable the invite modal
   ```ruby
   Feature.enable(:invite_members_group_modal)
   ```
1. In rails console enable the experiment fully
   ```ruby
   Feature.enable(:member_areas_of_focus)
   ```
1. Visit any group or project member pages such as `http://127.0.0.1:3000/groups/flightjs/-/group_members`
1. Click the `invite members` button.
-->

## MR acceptance checklist

This checklist encourages us to confirm any changes have been analyzed to reduce risks in quality, performance, reliability, security, and maintainability.

* [ ] I have read the [CONTRIBUTING.md](../../CONTRIBUTING.md) guide.
* [ ] The changes are correctly documented
* [ ] the CI is passing
* [ ] SonarCloud has validated the changes


/assign me
